==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sr/articles.php <==
<?php 
regGS("Select location:", "");
regGS("You cannot have two articles in the same section with the same name.  The article name you specified is already in use by the article '$1'.", "");
regGS("Visible to non-subscribers", "");
regGS("The article could not be published.", "");
regGS("Scheduled action deleted.", "");
regGS("Scheduled action added.", "");
regGS("Article(s) unlocked.", "");
regGS("Article(s) duplicated.", "");
regGS("Article(s) deleted.", "");
regGS("Article status set to '$1'", "");
regGS("Article unlocked.", "");
regGS("Article translation created.", "");
regGS("Article order changed.", "");
regGS("Article moved.", "");
regGS("Article deleted.", "");
regGS("Article created.", "");
regGS("$1 toggled.", "");
regGS("Total:", "");
regGS("Toggle '$1'", "");
regGS("Show Comments", "");
regGS("Saved:", "");
regGS("Locked", "");
regGS("Link to public page", "");
regGS("Invalid type: $1", "");
regGS("Hide Comments", "");
regGS("Enabled", "");
regGS("Disabled", "");
regGS("Comments:", "");
regGS("Comments", "");
regGS("The article has already been translated into $1.", "Текст је већ преведен на $1.");
regGS("You must set the publication, issue, and section for this article before you can schedule it for publishing.  Go to the \"$1\" menu and select \"$2\" to do this.", "Морате одредити публикацију, издање и рубрику за овај текст пре него што му закажете аутоматско објављивање, Идите у мени \"$1\" и изаберите \"$2\"");
regGS("You do not have the right to translate articles.", "Немате право да преводите текстове.");
regGS("You do not have the right to publish articles.", "Немате право да објављујете текстове.");
regGS("You do not have the right to move articles.", "Немате право да премештате текстове.");
regGS("You cannot $1 the articles marked in red because the destination issue has not been translated into the appropriate language.", "Не можете вршити радњу \"$1\" на текстовима наглашеним црвеном бојом јер циљно издање није преведено на одговарајући језик.");
regGS("Publish?", "Објави?");
regGS("Publish articles", "Објави текстове");
regGS("Publish article", "Објави текст");
regGS("Move?", "Премести?");
regGS("Move articles", "Премести текстове");
regGS("Move article", "Премести текст");
regGS("An issue must be created for the selected language but you do not have the right to create an issue.", "Мора бити креирано издање за одабрани језик, али ви немате право да креирате издање.");
regGS("A section must be created for the selected language but you do not have the right to create a section.", "Мора бити креирана рубрика за одабрани језик, али ви немате право да креирате рубрику.");
regGS("to section", "у рубрику");
regGS("You must select at least one article to perform an action.", "Морате изабрати најмање један текст да би радња била извршена.");
regGS("You must choose a language", "Морате изабрати језик");
regGS("You may only translate one article at a time.", "Можете преводити само један текст у једном тренутку.");
regGS("View article", "Погледај текст");
regGS("Unable to create the section for translation $1.", "Не може бити креирана рубрика за превод $1.");
regGS("Unable to create the issue for translation $1.", "Не може бити креирано издање за превод $1.");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Следећи текстови су нови; немогуће је предвидети их за аутоматско објављивање");
regGS("Status: Submitted", "Статус: предат");
regGS("Status: Submit", "Статус: предај");
regGS("Status: Set New", "Статус: постави нови");
regGS("Status: Published", "Статус: објављен");
regGS("Status: Publish", "Статус: објави");
regGS("Status: New", "Статус: нови");
regGS("Section URL Name", "УРЛ име рубрике");
regGS("Section Name", "Име рубрике");
regGS("Publish date", "Датум објављивања");
regGS("Publish Schedule", "Распоред објављивања");
regGS("No action specified", "Није предвиђена никаква радња");
regGS("New section name", "Ново име рубрике");
regGS("New section URL name", "Ново УРЛ име рубрике");
regGS("New issue name", "Ново име издања");
regGS("New issue URL name", "Ново УРЛ име издања");
regGS("New article name", "Ново име текста");
regGS("Issue URL Name", "УРЛ име издања");
regGS("Issue Name", "Име издања");
regGS("Files", "Фајлови");
regGS("Duplicate?", "Дуплирај?");
regGS("Duplicate to another section", "Дуплирај у другу рубрику");
regGS("Duplicate articles", "Дуплирај текстове");
regGS("Article name ($1)", "Наслов текста ($1)");
regGS("Article List", "Листа текстова");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Да ли сте сигурни да из текста желите да уклоните тему \'$1\'?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Да ли сте сигурни да из текста желите да уклоните фајл \'$1\'?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Да ли сте сигурни да желите да уклоните заказану акцију за $1?");
regGS("Are you sure you want to delete this article?", "Да ли сте сигурни да желите да обришете текст?");
regGS("Are you sure you want to delete the selected articles?", "Да ли сте сигурни да желите да обришете изабране текстове?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Мора бити креирано издање за одабрани језик. Унесите име издања и УРЛ име.");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Мора бити креирана рубрика за одабрани језик. Унесите име рубрике и УРЛ име.");
regGS("Article Type", "Тип текста");
regGS("$1 articles found", "Пронађено је $1 текстова");
regGS("Show article on front page", "Прикажи текст на почетној страни");
regGS("Show article on section page", "Прикажи текст на страни рубрике");
regGS("Translate article", "Преведи текст");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Немате право да мењате текст. Можете прегледати једино сопствене текстове, а једном предати текст може бити мењан само од стране овлашћених корисника");
regGS("Edit article", "Уреди текст");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "Текст је закључан од стране $1 ($2) пре $3 час(ов)а и $4 минута. ");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "Текст је закључан од стране $1 ($2) пре $3 минута.");
regGS("Article is locked", "Текст је закључан");
regGS("Duplicate article", "Дуплирај текст");
regGS("The destination section is the same as the source section.", "Циљна рубрика је иста као матична рубрика.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Текст има статус нови; није могуће заказати му акцију аутоматског објављивања.");
regGS("No article types were defined. You must create an article type first.", "Нема дефинисаних типова тесктова. Морате креирати неки.");
regGS("Edit article types", "Прикажи типове текстова");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Текст не може бити снимљен. Закључан је од стране $1 пре $2 часова и $3 минута.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Немате право да мењате статус текста. Предатом чланку статус може променити само овлашћени корисник.");
regGS("You do not have the right to delete articles.", "Немате право да бришете текстове.");
regGS("You must select an article type.", "Морате изабрати тип текста.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Да ли сте сигурни да из текста желите да уклоните слику \'$1\'?");
regGS("Reorder", "Промени распоред");
regGS("Author", "аутор");
regGS("Are you sure you want to delete this scheduled action?", " ");
regGS("Are you sure you want to remove the image '$1' from the article?", "Да ли сте сигурни да желите да обришете слику  '$1'  из текста? ");
regGS("There was an error reading request parameters.", "Дошло је до грешке при читању тражених параметара.");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "Чланак не може бити прегелдан. Проверите да ли је одређен шаблон за приказ чланка.");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "Овај чланак не може бити приказан. Проверите да ли је одређен шаблон за приказ почетне стране. ");
regGS("Insert Internal Link", "Направи интерни линк");
regGS("No such article.", "Нема таквог текста.");
regGS("No such section.", "Нема те рубрике.");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sr/articles.php <==
<?php 
regGS("Select location:", "Изабери локацију:");
regGS("You cannot have two articles in the same section with the same name.  The article name you specified is already in use by the article '$1'.", "Не можете имати два чланка у једној рубрици са истим именом. Наслов који сте унели је већ употребљен за чланак '$1'");
regGS("Visible to non-subscribers", "Видљиво непријављеним корисницима");
regGS("The article could not be published.", "Чланак не може бити објављен");
regGS("Scheduled action deleted.", "Заказане акције су обрисане");
regGS("Scheduled action added.", "Акција је заказана");
regGS("Article(s) unlocked.", "Чланак(а) откључан(о)");
regGS("Article(s) duplicated.", "Чланак(а) дуплиран(о)");
regGS("Article(s) deleted.", "Чланак(а) откључанобрисан(о)");
regGS("Article status set to '$1'", "Статус чланка постављен на '$1'");
regGS("Article unlocked.", "Чланак је откључан");
regGS("Article translation created.", "Направљен је превод чланка");
regGS("Article order changed.", "Редослед чланака је промењен");
regGS("Article moved.", "Чланак је премештен");
regGS("Article deleted.", "Чланак је обрисан");
regGS("Article created.", "Чланак је креиран");
regGS("$1 toggled.", "$1 toggled.");
regGS("Total:", "Укупно:");
regGS("Toggle '$1'", "Toggle '$1'");
regGS("Show Comments", "Прикажи коментаре");
regGS("Saved:", "Симљено:");
regGS("Locked", "Закључано");
regGS("Link to public page", "Линк ка страни са чланком");
regGS("Invalid type: $1", "Погрешан тип: $1");
regGS("Hide Comments", "Сакри коментаре");
regGS("Enabled", "Укључени");
regGS("Disabled", "Искључени");
regGS("Comments:", "Коментари:");
regGS("Comments", "Коментари");
regGS("The article has already been translated into $1.", "Текст је већ преведен на $1.");
regGS("You must set the publication, issue, and section for this article before you can schedule it for publishing.  Go to the \"$1\" menu and select \"$2\" to do this.", "Морате одредити публикацију, издање и рубрику за овај текст пре него што му закажете аутоматско објављивање, Идите у мени \"$1\" и изаберите \"$2\"");
regGS("You do not have the right to translate articles.", "Немате право да преводите текстове.");
regGS("You do not have the right to publish articles.", "Немате право да објављујете текстове.");
regGS("You do not have the right to move articles.", "Немате право да премештате текстове.");
regGS("You cannot $1 the articles marked in red because the destination issue has not been translated into the appropriate language.", "Не можете вршити радњу \"$1\" на текстовима наглашеним црвеном бојом јер циљно издање није преведено на одговарајући језик.");
regGS("Publish?", "Објави?");
regGS("Publish articles", "Објави текстове");
regGS("Publish article", "Објави текст");
regGS("Move?", "Премести?");
regGS("Move articles", "Премести текстове");
regGS("Move article", "Премести текст");
regGS("An issue must be created for the selected language but you do not have the right to create an issue.", "Мора бити креирано издање за одабрани језик, али ви немате право да креирате издање.");
regGS("A section must be created for the selected language but you do not have the right to create a section.", "Мора бити креирана рубрика за одабрани језик, али ви немате право да креирате рубрику.");
regGS("to section", "у рубрику");
regGS("You must select at least one article to perform an action.", "Морате изабрати најмање један текст да би радња била извршена.");
regGS("You must choose a language", "Морате изабрати језик");
regGS("You may only translate one article at a time.", "Можете преводити само један текст у једном тренутку.");
regGS("View article", "Погледај текст");
regGS("Unable to create the section for translation $1.", "Не може бити креирана рубрика за превод $1.");
regGS("Unable to create the issue for translation $1.", "Не може бити креирано издање за превод $1.");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Следећи текстови су нови; немогуће је предвидети их за аутоматско објављивање");
regGS("Status: Submitted", "Статус: предат");
regGS("Status: Submit", "Статус: предај");
regGS("Status: Set New", "Статус: постави нови");
regGS("Status: Published", "Статус: објављен");
regGS("Status: Publish", "Статус: објави");
regGS("Status: New", "Статус: нови");
regGS("Section URL Name", "УРЛ име рубрике");
regGS("Section Name", "Име рубрике");
regGS("Publish date", "Датум објављивања");
regGS("Publish Schedule", "Распоред објављивања");
regGS("No action specified", "Није предвиђена никаква радња");
regGS("New section name", "Ново име рубрике");
regGS("New section URL name", "Ново УРЛ име рубрике");
regGS("New issue name", "Ново име издања");
regGS("New issue URL name", "Ново УРЛ име издања");
regGS("New article name", "Ново име текста");
regGS("Issue URL Name", "УРЛ име издања");
regGS("Issue Name", "Име издања");
regGS("Files", "Фајлови");
regGS("Duplicate?", "Дуплирај?");
regGS("Duplicate to another section", "Дуплирај у другу рубрику");
regGS("Duplicate articles", "Дуплирај текстове");
regGS("Article name ($1)", "Наслов текста ($1)");
regGS("Article List", "Листа текстова");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Да ли сте сигурни да из текста желите да уклоните тему \'$1\'?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Да ли сте сигурни да из текста желите да уклоните фајл \'$1\'?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Да ли сте сигурни да желите да уклоните заказану акцију за $1?");
regGS("Are you sure you want to delete this article?", "Да ли сте сигурни да желите да обришете текст?");
regGS("Are you sure you want to delete the selected articles?", "Да ли сте сигурни да желите да обришете изабране текстове?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Мора бити креирано издање за одабрани језик. Унесите име издања и УРЛ име.");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Мора бити креирана рубрика за одабрани језик. Унесите име рубрике и УРЛ име.");
regGS("Article Type", "Тип текста");
regGS("$1 articles found", "Пронађено је $1 текстова");
regGS("Show article on front page", "Прикажи текст на почетној страни");
regGS("Show article on section page", "Прикажи текст на страни рубрике");
regGS("Translate article", "Преведи текст");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Немате право да мењате текст. Можете прегледати једино сопствене текстове, а једном предати текст може бити мењан само од стране овлашћених корисника");
regGS("Edit article", "Уреди текст");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "Текст је закључан од стране $1 ($2) пре $3 час(ов)а и $4 минута. ");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "Текст је закључан од стране $1 ($2) пре $3 минута.");
regGS("Article is locked", "Текст је закључан");
regGS("Duplicate article", "Дуплирај текст");
regGS("The destination section is the same as the source section.", "Циљна рубрика је иста као матична рубрика.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Текст има статус нови; није могуће заказати му акцију аутоматског објављивања.");
regGS("No article types were defined. You must create an article type first.", "Нема дефинисаних типова тесктова. Морате креирати неки.");
regGS("Edit article types", "Прикажи типове текстова");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Текст не може бити снимљен. Закључан је од стране $1 пре $2 часова и $3 минута.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Немате право да мењате статус текста. Предатом чланку статус може променити само овлашћени корисник.");
regGS("You do not have the right to delete articles.", "Немате право да бришете текстове.");
regGS("You must select an article type.", "Морате изабрати тип текста.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Да ли сте сигурни да из текста желите да уклоните слику \'$1\'?");
regGS("There was an error reading request parameters.", "Дошло је до грешке при читању тражених параметара.");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "Чланак не може бити прегелдан. Проверите да ли је одређен шаблон за приказ чланка.");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "Овај чланак не може бити приказан. Проверите да ли је одређен шаблон за приказ почетне стране. ");
regGS("Insert Internal Link", "Направи интерни линк");
regGS("No such article.", "Нема таквог текста.");
regGS("No such section.", "Нема те рубрике.");
regGS("Reorder", "Промени распоред");
regGS("Author", "аутор");
regGS("Are you sure you want to delete this scheduled action?", " ");
regGS("Are you sure you want to remove the image '$1' from the article?", "Да ли сте сигурни да желите да обришете слику  '$1'  из текста? ");
regGS("Are you sure you want to remove the topic \\'$1\\' from the article?", "Да ли сте сигурни да из текста желите да уклоните тему \\'$1\\'?");
regGS("Are you sure you want to remove the file \\'$1\\' from the article?", "Да ли сте сигурни да из текста желите да уклоните фајл \\'$1\\'?");
regGS("Are you sure you want to remove the image \\'$1\\' from the article?", "Да ли сте сигурни да из текста желите да уклоните слику \\'$1\\'?");
?>
